--------------------------------------------------------------------------------
-- SubModule MulShifter_52
-- Created   8/14/2007
--------------------------------------------------------------------------------
library IEEE;
use IEEE.Std_Logic_1164.all;
use IEEE.Numeric_Std.all;

entity MulShifter_52 is
   port (
     a        : in    std_logic_vector(35 downto 0);
     b        : out   std_logic_vector(63 downto 0);
     sel      : in    std_logic_vector (1 downto 0);
     CLK      : in    std_logic
   );
end MulShifter_52;
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
architecture RTL of MulShifter_52 is

   --constant mulwidth : integer := 18;
   --constant width : integer := 48;
   --constant drop : integer := 25;

   signal s : std_logic_vector (103 downto 0);

begin
   shifter: process (a, sel) is
   begin
      case sel is
         -- ISB * LSB : shift 17 bits, sign extend
         when B"00" =>
            s(16 downto 0) <= (others => '0');
            s(52 downto 17) <= a;
            s(103 downto 53) <= (others => a(a'left));
         -- MSB * LSB or ISB * ISB: shift 34 bits, sign extend
         when B"01" =>
            s(33 downto 0) <= (others => '0');
            s(69 downto 34) <= a;
            s(103 downto 70) <= (others => a(a'left));
         -- MSB * ISB: shift 51 bits, sign extend
         when B"10" =>
            s(50 downto 0) <= (others => '0');
            s(86 downto 51) <= a;
            s(103 downto 87) <= (others => a(a'left));
         -- MSB * MSB: shift 68 bits, own sign
         when B"11" =>
            s(67 downto 0) <= (others => '0');
            s(103 downto 68) <= a;
         when others =>
            s(103 downto 0) <= (others => '0');
      end case;
   end process shifter;
   -- output register
   b <= s(103) & s(103) & s(103) & s(103 downto 43) when rising_edge (CLK);
end architecture RTL;
--------------------------------------------------------------------------------
