--------------------------------------------------------------------------------
-- SubModule SlaveDiag
-- Created   8/12/2008 9:32:08 AM
--------------------------------------------------------------------------------
library IEEE;
use IEEE.Std_Logic_1164.all;
use IEEE.Numeric_Std.all;

entity SlaveDiag is port
   (
     GPS              : in    std_logic_vector(31 downto 0);
     ADDR             : in    std_logic_vector(31 downto 0);
     SW               : in    std_logic_vector(10 downto 1);
     LOS              : in    std_logic;
     UP               : in    std_logic;
     ERRC             : in    std_logic_vector(3 downto 0);
     VCXO_CTRL        : in    std_logic_vector(15 downto 0);
     CRCERR           : in    std_logic_vector(7 downto 0);

     STAT             : out   std_logic_vector(1023 downto 0);

     A                : in    std_logic_vector(31 downto 0);
     B                : in    std_logic_vector(31 downto 0);
     C                : in    std_logic_vector(31 downto 0);
     D                : in    std_logic_vector(31 downto 0);
     E                : in    std_logic_vector(31 downto 0);
     F                : in    std_logic_vector(31 downto 0);
     G                : in    std_logic_vector(31 downto 0);
     H                : in    std_logic_vector(31 downto 0);
     I                : in    std_logic_vector(31 downto 0);
     J                : in    std_logic_vector(31 downto 0);
     K                : in    std_logic_vector(31 downto 0);
     L                : in    std_logic_vector(31 downto 0);
     M                : in    std_logic_vector(31 downto 0);
     N                : in    std_logic_vector(31 downto 0);
     O                : in    std_logic_vector(31 downto 0);
     P                : in    std_logic_vector(31 downto 0);
     Q                : in    std_logic_vector(31 downto 0);
     R                : in    std_logic_vector(31 downto 0);
     S                : in    std_logic_vector(31 downto 0);
     T                : in    std_logic_vector(31 downto 0);
     U                : in    std_logic_vector(31 downto 0);
     V                : in    std_logic_vector(31 downto 0);
     W                : in    std_logic_vector(31 downto 0)
   );
end SlaveDiag;
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
architecture Structure of SlaveDiag is

-- Component Declarations

-- Signal Declarations
   signal w0           : std_logic_vector (31 downto 0); -- board id/revision
   signal w1           : std_logic_vector (31 downto 0); -- board serial
   signal w2           : std_logic_vector (31 downto 0); -- software id
   signal w3           : std_logic_vector (31 downto 0); -- software revision
   signal w4           : std_logic_vector (31 downto 0); -- module address
   signal w5           : std_logic_vector (31 downto 0); -- GPS time
   signal w6           : std_logic_vector (31 downto 0); -- Status
   signal w7           : std_logic_vector (31 downto 0); -- Configuration
   signal z            : std_logic_vector (1023 downto 0);

begin
   -- board id/revision
   w0 <= X"070071B0";
   -- board serial
   w1 <= X"00000000";
   -- software id
   w2 <= X"080335B0";
   -- software revision
   w3 <= std_logic_vector (To_Unsigned (118, 32));

   -- GPS time
   w4 <= GPS;
   -- address
   w5 <= ADDR;

   -- Status
   w6 (31 downto 16) <= VCXO_CTRL;
   w6 (15 downto 8) <= SW(8 downto 1);
   w6 (7 downto 6) <= SW(10 downto 9);
   w6 (5) <= LOS;
   w6 (4 downto 1) <= ERRC;
   w6 (0) <= UP;

   w7 <= X"000000" & CRCERR;

   z <= w0 & w1 & w2 & w3 & w4 & w5 & w6 & w7 &
        A & B & C & D & E & F & G & H &
        I & J & K & L & M & N & O & P &
        Q & R & S & T & U & V & W & X"00000000";
   STAT <= z;

end Structure;
--------------------------------------------------------------------------------
