(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    220441,       4494]
NotebookOptionsPosition[    215709,       4364]
NotebookOutlinePosition[    216073,       4380]
CellTagsIndexPosition[    216030,       4377]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Sine Wave Generation \[LineSeparator]using the\[LineSeparator]Goertzel \
Algorithm\
\>", "Title",
 CellChangeTimes->{{3.4186454214565*^9, 3.418645427159625*^9}, {
  3.418647180644*^9, 3.41864718080025*^9}, {3.418651493628375*^9, 
  3.418651493753375*^9}, {3.418741189599125*^9, 3.418741209286625*^9}, {
  3.4187412418335*^9, 3.418741294130375*^9}}],

Cell["T080112-00", "Subsubtitle",
 CellChangeTimes->{{3.4186455109565*^9, 3.418645512597125*^9}, {
  3.41874132417725*^9, 3.418741327036625*^9}}],

Cell["\<\
Daniel Sigg
May 1st, 2008\
\>", "Subsubtitle",
 CellChangeTimes->{{3.4186455109565*^9, 3.418645512597125*^9}, {
  3.4187412254585*^9, 3.4187412312085*^9}}],

Cell[CellGroupData[{

Cell["Discrete Fourier Transform", "Section",
 CellChangeTimes->{{3.41864878967525*^9, 3.4186488107065*^9}}],

Cell["\<\
The Goertzel algorithm is the implementation of a discrete Fourier transform \
as a inifinite-impulse response filter. Let's consider\
\>", "Text",
 CellChangeTimes->{{3.418645523753375*^9, 3.41864560511275*^9}, {
  3.418646426565875*^9, 3.418646445065875*^9}, {3.418647310597125*^9, 
  3.4186473139565*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"H", "(", "z", ")"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", "-", 
       RowBox[{"W", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}]], "              ", "with", "   ", "W"}], 
    "=", 
    RowBox[{
     SuperscriptBox["e", 
      RowBox[{"2", "\[Pi]", " ", "i", " ", 
       RowBox[{"f", "/", 
        SubscriptBox["f", "N"]}]}]], "   ", "and", "    ", 
     SubscriptBox["f", "N"], " ", "the", " ", "Nyquist", " ", 
     RowBox[{"frequency", "."}]}]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864622730025*^9, 
   3.418646228847125*^9}, {3.418646623347125*^9, 3.418646632534625*^9}, 
   3.41864669961275*^9}],

Cell["\<\
The time domain representation of this filter is then given by\
\>", "Text",
 CellChangeTimes->{{3.418646717847125*^9, 3.418646744784625*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"y", "(", "n", ")"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "(", "n", ")"}], "+", 
     RowBox[{"W", " ", 
      RowBox[{"y", "(", 
       RowBox[{"n", "-", "1"}], ")"}]}]}], "=", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", 
        RowBox[{"-", "\[Infinity]"}]}], "n"], 
      RowBox[{
       SuperscriptBox["W", 
        RowBox[{"n", "-", "k"}]], 
       RowBox[{"x", "(", "k", ")"}]}]}], "=", 
     RowBox[{
      SuperscriptBox["W", "n"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", 
         RowBox[{"-", "\[Infinity]"}]}], "n"], 
       RowBox[{
        SuperscriptBox["W", 
         RowBox[{"-", "k"}]], 
        RowBox[{"x", "(", "k", ")"}]}]}]}]}]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864622730025*^9, 
   3.418646228847125*^9}, {3.418646623347125*^9, 3.418646632534625*^9}, 
   3.41864669961275*^9, {3.41864675748775*^9, 3.41864678348775*^9}, {
   3.41864690955025*^9, 3.4186469540815*^9}, {3.418646994284625*^9, 
   3.418647091972125*^9}, {3.418670483503375*^9, 3.418670484440875*^9}}],

Cell[TextData[{
 "If we set x ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", "k", ")"}], "=", "0"}], TraditionalForm]]],
 " for all ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "<", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "=", "N"}], TraditionalForm]]],
 ", we get"
}], "Text",
 CellChangeTimes->{{3.4186470969565*^9, 3.418647115659625*^9}, {
  3.418647149769*^9, 3.418647169440875*^9}, {3.418647204253375*^9, 
  3.4186472194565*^9}, {3.41865347830025*^9, 3.418653505003375*^9}, {
  3.418653546284625*^9, 3.41865354867525*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"y", "(", "N", ")"}], "=", 
   RowBox[{
    SuperscriptBox["W", "N"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], 
      RowBox[{"N", "-", "1"}]], 
     RowBox[{
      SuperscriptBox["W", 
       RowBox[{"-", "k"}]], 
      RowBox[{"x", "(", "k", ")"}]}]}]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864622730025*^9, 
   3.418646228847125*^9}, {3.418646623347125*^9, 3.418646632534625*^9}, 
   3.41864669961275*^9, {3.41864675748775*^9, 3.41864678348775*^9}, {
   3.41864690955025*^9, 3.4186469540815*^9}, {3.418646994284625*^9, 
   3.418647091972125*^9}, {3.418647245628375*^9, 3.418647254097125*^9}, {
   3.41865297186275*^9, 3.418652979003375*^9}, {3.41865350855025*^9, 
   3.418653520253375*^9}}],

Cell[TextData[{
 "which corresponds to the discrete Fourier term at frequency ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " with an additional scale factor ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["W", "N"], TraditionalForm]]],
 ". If we want to comnpute the standard discrete Fourier transform, the above \
expression has to be evaluate for all ",
 Cell[BoxData[
  FormBox["W", TraditionalForm]]],
 " of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["W", "k"], "=", 
    SuperscriptBox["e", 
     RowBox[{"2", "\[Pi]", " ", "i", " ", 
      RowBox[{"k", "/", "N"}]}]]}], TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"k", "=", "0"}], ",", "1", ",", "...", ",", 
    RowBox[{"N", "-", "1"}]}], TraditionalForm]]],
 ". In this case we get ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["W", "N"], "=", "1"}], TraditionalForm]]],
 ". By setting up filters for all ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["W", "k"], TraditionalForm]]],
 " we will get all the terms of a discrete Fourirer transform in an albeit \
inefficiecient fashion. However, if we are only interested in a single or a \
few terms, this algorithm is more efficient than computing a full FFT."
}], "Text",
 CellChangeTimes->{{3.418647273003375*^9, 3.418647293565875*^9}, {
  3.418647327315875*^9, 3.418647674409625*^9}, {3.418647718440875*^9, 
  3.418647798284625*^9}, {3.418647851159625*^9, 3.41864794286275*^9}, {
  3.418653036159625*^9, 3.418653056003375*^9}, {3.418653293097125*^9, 
  3.418653293190875*^9}, {3.418653334722125*^9, 3.4186533415815*^9}, {
  3.418653534769*^9, 3.418653535940875*^9}, {3.418653648472125*^9, 
  3.41865378123775*^9}, {3.4186539017065*^9, 3.4186539240815*^9}}],

Cell[TextData[{
 "Going back to equation (1) this is strictly speaking not an IIR filter, \
because it consists of a single complex pole. We can fix this by multiplying \
by ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{
      RowBox[{"W", "\[Conjugate]"}], " ", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}]}], ")"}], TraditionalForm]]],
 " both in the denominator and the numerator"
}], "Text",
 CellChangeTimes->{{3.41864595955025*^9, 3.41864601480025*^9}, {
  3.41864616736275*^9, 3.41864620092525*^9}, {3.418646236409625*^9, 
  3.41864624573775*^9}, {3.418646704159625*^9, 3.418646705378375*^9}, {
  3.418647960644*^9, 3.418647986269*^9}, {3.418648528519*^9, 
  3.418648544534625*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"H", "(", "z", ")"}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"1", "-", 
      RowBox[{
       RowBox[{"W", "\[Conjugate]"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}]}], 
     RowBox[{"1", "-", 
      RowBox[{"2", 
       RowBox[{"cos", "(", 
        RowBox[{"2", "\[Pi]", " ", 
         RowBox[{"f", "/", 
          SubscriptBox["f", "N"]}]}], ")"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]], "."}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864620748775*^9, 
   3.418646208940875*^9}, {3.418646254753375*^9, 3.41864631423775*^9}, 
   3.418646353690875*^9, {3.418646709628375*^9, 3.418646710909625*^9}}],

Cell["\<\
Now we have a normal two-pole filter followd by a complex zero. In the time \
domain this corresponds to\
\>", "Text",
 CellChangeTimes->{{3.418646318034625*^9, 3.4186463298315*^9}, {
  3.41864637186275*^9, 3.41864638461275*^9}, {3.418648020128375*^9, 
  3.418648044440875*^9}, {3.418653997659625*^9, 3.418653998128375*^9}}],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{"v", "(", "n", ")"}], "=", 
   RowBox[{
    RowBox[{"2", 
     RowBox[{"cos", "(", 
      RowBox[{"2", "\[Pi]", " ", 
       RowBox[{"f", "/", 
        SubscriptBox["f", "N"]}]}], ")"}], " ", 
     RowBox[{"v", "(", 
      RowBox[{"n", "-", "1"}], ")"}]}], "-", 
    RowBox[{"v", "(", 
     RowBox[{"n", "-", "2"}], ")"}], "+", 
    RowBox[{
     RowBox[{"x", "(", "n", ")"}], "   ", "and"}]}]}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{"y", "(", "n", ")"}], "=", 
   RowBox[{
    RowBox[{"v", "(", "n", ")"}], "-", 
    RowBox[{
     RowBox[{"W", "\[Conjugate]"}], 
     RowBox[{
      RowBox[{"v", "(", 
       RowBox[{"n", "-", "1"}], ")"}], "."}]}]}]}], 
  TraditionalForm]}], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864620748775*^9, 
   3.418646208940875*^9}, {3.418646254753375*^9, 3.41864631423775*^9}, 
   3.418646353690875*^9, {3.418646709628375*^9, 3.418646710909625*^9}, {
   3.41864806005025*^9, 3.418648141753375*^9}, {3.4186540613315*^9, 
   3.418654064144*^9}}],

Cell[TextData[{
 "The key insighth is that the first line corresponds to a second-order \
filter section with fixed real coeffiecients. However, the second line which \
involves a complex multiplication only needs to be computed once at the very \
end for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "(", "N", ")"}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.41864817648775*^9, 3.4186482530815*^9}, {
  3.418648298019*^9, 3.418648329940875*^9}, {3.418654073690875*^9, 
  3.418654099034625*^9}, {3.418654146753375*^9, 3.418654185909625*^9}}],

Cell["\<\
The second line of equation (5) employs a complex coffient because we are \
interested in the complex Fourier coeffcient. If we were to look for the real \
part, the imaginary part or the amplitude along a single direction \[Psi] in \
the complex plane only, we can rewrite equation (5) in the usual direct form \
II structure\
\>", "Text",
 CellChangeTimes->{{3.418648866253375*^9, 3.418649071597125*^9}, {
  3.418649138394*^9, 3.41864920748775*^9}, {3.4186495304565*^9, 
  3.418649531565875*^9}, {3.41864961573775*^9, 3.418649637315875*^9}, {
  3.418650078690875*^9, 3.41865008955025*^9}, {3.41865420280025*^9, 
  3.4186542133315*^9}}],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{"v", "(", "n", ")"}], "=", 
   RowBox[{
    RowBox[{"x", "(", "n", ")"}], "+", 
    RowBox[{
     SubscriptBox["a", "1"], 
     RowBox[{"v", "(", 
      RowBox[{"n", "-", "1"}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["a", "2"], 
     RowBox[{"v", "(", 
      RowBox[{"n", "-", "2"}], ")"}]}]}]}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{"y", "(", "n", ")"}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "0"], " ", 
     RowBox[{"v", "(", "n", ")"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "1"], "v", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"n", "-", "1"}], ")"}], "."}]}]}]}], 
  TraditionalForm]}], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864620748775*^9, 
   3.418646208940875*^9}, {3.418646254753375*^9, 3.41864631423775*^9}, 
   3.418646353690875*^9, {3.418646709628375*^9, 3.418646710909625*^9}, {
   3.41864806005025*^9, 3.418648141753375*^9}, {3.418649228472125*^9, 
   3.418649230065875*^9}, {3.418649273190875*^9, 3.418649293503375*^9}, {
   3.418649460128375*^9, 3.418649521534625*^9}, {3.41864964367525*^9, 
   3.418649644472125*^9}, {3.418649679034625*^9, 3.418649715644*^9}, 
   3.418649843144*^9, {3.418650401690875*^9, 3.418650404003375*^9}, {
   3.418650946722125*^9, 3.418650955128375*^9}}],

Cell["Using ", "Text",
 CellChangeTimes->{{3.418649537190875*^9, 3.418649537972125*^9}, {
  3.4186498289565*^9, 3.418649840409625*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["H", "sos"], "=", 
   RowBox[{"(", GridBox[{
      {"1", 
       SubscriptBox["a", "1"], 
       SubscriptBox["a", "2"]},
      {
       SubscriptBox["b", "0"], 
       SubscriptBox["b", "1"], 
       SubscriptBox["b", "2"]}
     }], ")"}]}], TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864620748775*^9, 
   3.418646208940875*^9}, {3.418646254753375*^9, 3.41864631423775*^9}, 
   3.418646353690875*^9, {3.418646709628375*^9, 3.418646710909625*^9}, {
   3.41864806005025*^9, 3.418648141753375*^9}, {3.418649228472125*^9, 
   3.418649230065875*^9}, {3.418649273190875*^9, 3.418649293503375*^9}, {
   3.418649460128375*^9, 3.418649521534625*^9}, {3.41864964367525*^9, 
   3.418649644472125*^9}, {3.418649679034625*^9, 3.418649715644*^9}, {
   3.418649767753375*^9, 3.418649853769*^9}, {3.4186499152065*^9, 
   3.418649917940875*^9}, {3.41864998273775*^9, 3.4186500124565*^9}, 
   3.41865095736275*^9}],

Cell["we get", "Text",
 CellChangeTimes->{{3.418649893144*^9, 3.418649895440875*^9}, {
  3.418650034909625*^9, 3.41865003580025*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["H", "sos"], "(", "Re", ")"}], "=", 
    RowBox[{"(", GridBox[{
       {"1", 
        RowBox[{"2", "cos", 
         RowBox[{"(", 
          RowBox[{"2", "\[Pi]", " ", 
           RowBox[{"f", "/", 
            SubscriptBox["f", "N"]}]}], ")"}]}], 
        RowBox[{"-", "1"}]},
       {"1", 
        RowBox[{"-", 
         RowBox[{"cos", "(", 
          RowBox[{"2", "\[Pi]", " ", 
           RowBox[{"f", "/", 
            SubscriptBox["f", "N"]}]}], ")"}]}], "0"}
      }], ")"}]}], ","}], TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864620748775*^9, 
   3.418646208940875*^9}, {3.418646254753375*^9, 3.41864631423775*^9}, 
   3.418646353690875*^9, {3.418646709628375*^9, 3.418646710909625*^9}, {
   3.41864806005025*^9, 3.418648141753375*^9}, {3.418649228472125*^9, 
   3.418649230065875*^9}, {3.418649273190875*^9, 3.418649293503375*^9}, {
   3.418649460128375*^9, 3.418649521534625*^9}, {3.41864964367525*^9, 
   3.418649644472125*^9}, {3.418649679034625*^9, 3.418649715644*^9}, {
   3.418649767753375*^9, 3.418649853769*^9}, {3.41864994492525*^9, 
   3.4186500164565*^9}, {3.41865010305025*^9, 3.41865015698775*^9}, 
   3.4186507639565*^9, 3.418650863644*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["H", "sos"], "(", "Im", ")"}], "=", 
   RowBox[{
    RowBox[{"(", GridBox[{
       {"1", 
        RowBox[{"2", "cos", 
         RowBox[{"(", 
          RowBox[{"2", "\[Pi]", " ", 
           RowBox[{"f", "/", 
            SubscriptBox["f", "N"]}]}], ")"}]}], 
        RowBox[{"-", "1"}]},
       {"0", 
        RowBox[{"sin", 
         RowBox[{"(", 
          RowBox[{"2", "\[Pi]", " ", 
           RowBox[{"f", "/", 
            SubscriptBox["f", "N"]}]}], ")"}]}], "0"}
      }], ")"}], "   ", "and"}]}], TraditionalForm]], "DisplayFormulaNumbered",\

 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864620748775*^9, 
   3.418646208940875*^9}, {3.418646254753375*^9, 3.41864631423775*^9}, 
   3.418646353690875*^9, {3.418646709628375*^9, 3.418646710909625*^9}, {
   3.41864806005025*^9, 3.418648141753375*^9}, {3.418649228472125*^9, 
   3.418649230065875*^9}, {3.418649273190875*^9, 3.418649293503375*^9}, {
   3.418649460128375*^9, 3.418649521534625*^9}, {3.41864964367525*^9, 
   3.418649644472125*^9}, {3.418649679034625*^9, 3.418649715644*^9}, {
   3.418649767753375*^9, 3.418649853769*^9}, {3.41864994492525*^9, 
   3.4186500164565*^9}, {3.41865010305025*^9, 3.418650164097125*^9}, {
   3.41865019936275*^9, 3.418650211659625*^9}, {3.418650374503375*^9, 
   3.41865037773775*^9}, 3.418650865378375*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["H", "sos"], "(", "\[Psi]", ")"}], "=", 
   RowBox[{
    RowBox[{"(", GridBox[{
       {"1", 
        RowBox[{"2", "cos", 
         RowBox[{"(", 
          RowBox[{"2", "\[Pi]", " ", 
           RowBox[{"f", "/", 
            SubscriptBox["f", "N"]}]}], ")"}]}], 
        RowBox[{"-", "1"}]},
       {
        RowBox[{"cos", "(", "\[Psi]", ")"}], 
        RowBox[{"-", 
         RowBox[{"cos", "(", 
          RowBox[{
           RowBox[{"2", "\[Pi]", " ", 
            RowBox[{"f", "/", 
             SubscriptBox["f", "N"]}]}], "+", "\[Psi]"}], ")"}]}], "0"}
      }], ")"}], "."}]}], TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864620748775*^9, 
   3.418646208940875*^9}, {3.418646254753375*^9, 3.41864631423775*^9}, 
   3.418646353690875*^9, {3.418646709628375*^9, 3.418646710909625*^9}, {
   3.41864806005025*^9, 3.418648141753375*^9}, {3.418649228472125*^9, 
   3.418649230065875*^9}, {3.418649273190875*^9, 3.418649293503375*^9}, {
   3.418649460128375*^9, 3.418649521534625*^9}, {3.41864964367525*^9, 
   3.418649644472125*^9}, {3.418649679034625*^9, 3.418649715644*^9}, {
   3.418649767753375*^9, 3.418649853769*^9}, {3.41864994492525*^9, 
   3.4186500164565*^9}, {3.41865010305025*^9, 3.41865015698775*^9}, {
   3.418650279019*^9, 3.4186502918315*^9}, 3.418650570315875*^9, {
   3.418650616409625*^9, 3.418650630159625*^9}, 3.41865086780025*^9}],

Cell[TextData[{
 "Two things are noteworthy. First, in implementations of second-order filter \
sections the term ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "0"], TraditionalForm]]],
 " is often pulled out as an overall gain factor by setting it to 1. This is \
not possible here when we are looking for the imaginary part. We can avoid \
this by using  "
}], "Text",
 CellChangeTimes->{{3.4186510238315*^9, 3.418651037753375*^9}, {
  3.418651105597125*^9, 3.4186512149565*^9}, {3.418651301347125*^9, 
  3.418651318878375*^9}, {3.4186514182065*^9, 3.41865145330025*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["H", "sos"], "(", "Im", ")"}], "=", 
   RowBox[{"(", GridBox[{
      {"1", 
       RowBox[{"2", "cos", 
        RowBox[{"(", 
         RowBox[{"2", "\[Pi]", " ", 
          RowBox[{"f", "/", 
           SubscriptBox["f", "N"]}]}], ")"}]}], 
       RowBox[{"-", "1"}]},
      {
       RowBox[{"sin", 
        RowBox[{"(", 
         RowBox[{"2", "\[Pi]", " ", 
          RowBox[{"f", "/", 
           SubscriptBox["f", "N"]}]}], ")"}]}], "0", "0"}
     }], ")"}], " "}], TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864620748775*^9, 
   3.418646208940875*^9}, {3.418646254753375*^9, 3.41864631423775*^9}, 
   3.418646353690875*^9, {3.418646709628375*^9, 3.418646710909625*^9}, {
   3.41864806005025*^9, 3.418648141753375*^9}, {3.418649228472125*^9, 
   3.418649230065875*^9}, {3.418649273190875*^9, 3.418649293503375*^9}, {
   3.418649460128375*^9, 3.418649521534625*^9}, {3.41864964367525*^9, 
   3.418649644472125*^9}, {3.418649679034625*^9, 3.418649715644*^9}, {
   3.418649767753375*^9, 3.418649853769*^9}, {3.41864994492525*^9, 
   3.4186500164565*^9}, {3.41865010305025*^9, 3.418650164097125*^9}, {
   3.41865019936275*^9, 3.418650211659625*^9}, {3.418650374503375*^9, 
   3.41865037773775*^9}, 3.418650865378375*^9, {3.418651325519*^9, 
   3.418651338440875*^9}, 3.4186513752065*^9}],

Cell[TextData[{
 "instead, and looking at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "(", 
    RowBox[{"n", "-", "1"}], ")"}], TraditionalForm]]],
 " rather than ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "(", "n", ")"}], TraditionalForm]]],
 ". Secondly, one might also be interested in the absolute value or the phase \
angle. This is straight forward to compute but will no longer constitute a \
linear filter. For example,"
}], "Text",
 CellChangeTimes->{{3.418651343628375*^9, 3.418651403394*^9}, {
   3.418651467315875*^9, 3.41865158892525*^9}, 3.41865424686275*^9}],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{"r", "(", "n", ")"}], "=", 
   RowBox[{
    SqrtBox[
     RowBox[{" ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"v", "(", 
         RowBox[{"n", "-", "1"}], ")"}], "2"], "-", 
       RowBox[{"2", 
        RowBox[{"cos", "(", 
         RowBox[{"2", "\[Pi]", " ", 
          RowBox[{"f", "/", 
           SubscriptBox["f", "N"]}]}], ")"}], 
        RowBox[{"v", "(", 
         RowBox[{"n", "-", "1"}], ")"}], 
        RowBox[{"v", "(", 
         RowBox[{"n", "-", "2"}], ")"}]}], "+", 
       SuperscriptBox[
        RowBox[{"v", "(", 
         RowBox[{"n", "-", "2"}], ")"}], "2"]}]}]], "   ", "and"}]}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{"\[CurlyPhi]", "(", "n", ")"}], "=", 
   RowBox[{"arctan", "(", 
    FractionBox[
     RowBox[{
      RowBox[{"sin", "(", 
       RowBox[{"2", "\[Pi]", " ", 
        RowBox[{"f", "/", 
         SubscriptBox["f", "N"]}]}], ")"}], 
      RowBox[{"v", "(", 
       RowBox[{"n", "-", "2"}], ")"}]}], 
     RowBox[{
      RowBox[{"v", "(", 
       RowBox[{"n", "-", "1"}], ")"}], "-", 
      RowBox[{
       RowBox[{"cos", "(", 
        RowBox[{"2", "\[Pi]", " ", 
         RowBox[{"f", "/", 
          SubscriptBox["f", "N"]}]}], ")"}], 
       RowBox[{"v", "(", 
        RowBox[{"n", "-", "2"}], ")"}]}]}]], ")"}]}], 
  TraditionalForm]}], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864620748775*^9, 
   3.418646208940875*^9}, {3.418646254753375*^9, 3.41864631423775*^9}, 
   3.418646353690875*^9, {3.418646709628375*^9, 3.418646710909625*^9}, {
   3.41864806005025*^9, 3.418648141753375*^9}, {3.418649228472125*^9, 
   3.418649230065875*^9}, {3.418649273190875*^9, 3.418649293503375*^9}, {
   3.418649460128375*^9, 3.418649521534625*^9}, {3.41864964367525*^9, 
   3.418649644472125*^9}, {3.418649679034625*^9, 3.418649715644*^9}, 
   3.418649843144*^9, {3.418650401690875*^9, 3.418650404003375*^9}, {
   3.418650946722125*^9, 3.418650955128375*^9}, {3.418651599894*^9, 
   3.418651615222125*^9}, {3.4186516498315*^9, 3.41865178592525*^9}, {
   3.418651824847125*^9, 3.4186518345815*^9}, {3.41865187523775*^9, 
   3.418651917815875*^9}, {3.4186520258315*^9, 3.418652088284625*^9}, {
   3.418652125222125*^9, 3.41865212592525*^9}}],

Cell[TextData[{
 "yield the absolute value and complex phase angle, respectively. Of course, \
the ",
 Cell[BoxData[
  FormBox["arctan", TraditionalForm]]],
 " function needs to take into account in which quadrant the complex number \
is in."
}], "Text",
 CellChangeTimes->{{3.418651743972125*^9, 3.41865175567525*^9}, {
  3.418651793269*^9, 3.418651812722125*^9}, {3.41865223536275*^9, 
  3.418652310159625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sine Wave Generation", "Section",
 CellChangeTimes->{{3.41864878967525*^9, 3.418648836269*^9}}],

Cell[TextData[{
 "The Goertzel algorithm can also be used to generate a sine wave. Consider \
the input series ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "(", "0", ")"}], "=", "1"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "(", "k", ")"}], "=", "0"}], TraditionalForm]]],
 " for all ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "\[NotEqual]", "0"}], TraditionalForm]]],
 ", we can see that equation (2) becomes simply"
}], "Text",
 CellChangeTimes->{{3.41865237330025*^9, 3.418652409065875*^9}, {
  3.418654395128375*^9, 3.418654581440875*^9}, {3.418654628315875*^9, 
  3.418654645159625*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"y", "(", "n", ")"}], "=", 
   RowBox[{
    SuperscriptBox["W", "n"], "=", 
    SuperscriptBox["e", 
     RowBox[{"2", "\[Pi]", " ", "i", "  ", "n", " ", 
      RowBox[{"f", "/", 
       SubscriptBox["f", "N"]}]}]]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864622730025*^9, 
   3.418646228847125*^9}, {3.418646623347125*^9, 3.418646632534625*^9}, 
   3.41864669961275*^9, {3.41864675748775*^9, 3.41864678348775*^9}, {
   3.41864690955025*^9, 3.4186469540815*^9}, {3.418646994284625*^9, 
   3.418647091972125*^9}, {3.41865460423775*^9, 3.418654622753375*^9}, {
   3.418654659472125*^9, 3.4186546883315*^9}}],

Cell["\<\
Taking the real part we get a pure cosine function, whereas the imaginary \
part yields the corresponding sine function.\
\>", "Text",
 CellChangeTimes->{{3.418654694472125*^9, 3.418654751909625*^9}}],

Cell[TextData[{
 "One problem which will occure for any real world implementation is that \
numerical round-off errors can accumulate over time. If the desired sine wave \
has an integer number of cycles within ",
 Cell[BoxData[
  FormBox["M", TraditionalForm]]],
 " samples, the filter can simply be restarted every ",
 Cell[BoxData[
  FormBox["M", TraditionalForm]]],
 " samples. This avoids the accumulation of numerical errors and the \
algorithm will give predictable results for any length of running."
}], "Text",
 CellChangeTimes->{{3.4186547835815*^9, 3.418654948253375*^9}, {
  3.41865498061275*^9, 3.418655168409625*^9}}],

Cell[TextData[{
 "If we are interested in a sine wave only, we can used ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["H", "sos"], "(", "Im", ")"}], TraditionalForm]],
  CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
    3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
    3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
    3.418646119019*^9, 3.41864615461275*^9}, {3.41864620748775*^9, 
    3.418646208940875*^9}, {3.418646254753375*^9, 3.41864631423775*^9}, 
    3.418646353690875*^9, {3.418646709628375*^9, 3.418646710909625*^9}, {
    3.41864806005025*^9, 3.418648141753375*^9}, {3.418649228472125*^9, 
    3.418649230065875*^9}, {3.418649273190875*^9, 3.418649293503375*^9}, {
    3.418649460128375*^9, 3.418649521534625*^9}, {3.41864964367525*^9, 
    3.418649644472125*^9}, {3.418649679034625*^9, 3.418649715644*^9}, {
    3.418649767753375*^9, 3.418649853769*^9}, {3.41864994492525*^9, 
    3.4186500164565*^9}, {3.41865010305025*^9, 3.418650164097125*^9}, {
    3.41865019936275*^9, 3.418650211659625*^9}, {3.418650374503375*^9, 
    3.41865037773775*^9}, 3.418650865378375*^9}],
 " from equation (11) and pull the factor ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "0"], TraditionalForm]]],
 " into the input series. We then get ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "(", "n", ")"}], "=", 
    RowBox[{"v", "(", "n", ")"}]}], TraditionalForm]]],
 " and the filter reduces to a complex pole only. To start the sine wave at \
zero, we restart the algorithm at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", 
    RowBox[{"l", " ", "M"}]}], TraditionalForm]]],
 "with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"l", "=", "0"}], ",", " ", "1", ",", " ", "2", ",", " ", "..."}], 
   TraditionalForm]]],
 ", we set the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "(", 
     RowBox[{"l", " ", "M"}], ")"}], "=", "0"}], TraditionalForm]]],
 " and use the following input series"
}], "Text",
 CellChangeTimes->{{3.418655287597125*^9, 3.41865576042525*^9}, {
  3.418655886190875*^9, 3.4186558899565*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", "(", "k", ")"}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"l", "=", 
      RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["\[Delta]", 
      RowBox[{"k", ",", 
       RowBox[{
        RowBox[{"l", " ", "M"}], "+", "1"}]}]], " ", 
     RowBox[{"sin", "(", 
      RowBox[{"2", "\[Pi]", " ", 
       RowBox[{"f", "/", 
        SubscriptBox["f", "N"]}]}], ")"}]}]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.418655776128375*^9, 3.418655776878375*^9}, {
  3.41865583430025*^9, 3.418655901909625*^9}}],

Cell[TextData[{
 "with \[Delta] the Kronecker delta. This later algorithm has the advantage \
that the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"v", "(", "n", ")"}], TraditionalForm]]],
 " are always contained within ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"+", "1"}], TraditionalForm]]],
 ". It is therefore suitable for implementations which use fixed point number \
arithmetic. For a fixed point implementation of a cosine function we need a \
different approach. Consider the trigonometric series ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"sin", "(", 
     RowBox[{
      SubscriptBox["\[Alpha]", "0"], "+", 
      RowBox[{"n", " ", "\[Alpha]"}]}], ")"}], " ", "and", " ", 
    RowBox[{"cos", "(", 
     RowBox[{
      SubscriptBox["\[Alpha]", "0"], "+", 
      RowBox[{"n", " ", "\[Alpha]"}]}], ")"}]}], TraditionalForm]]],
 " with n = 0, 1, ..., ",
 Cell[BoxData[
  FormBox[
   RowBox[{"N", "-", "1"}], TraditionalForm]]],
 ". We make the ansatz"
}], "Text",
 CellChangeTimes->{{3.41865577917525*^9, 3.418655790753375*^9}, {
  3.418655934894*^9, 3.418656039065875*^9}, {3.4186560754565*^9, 
  3.41865619980025*^9}, {3.41865623205025*^9, 3.4186562730815*^9}, {
  3.41865632248775*^9, 3.418656405253375*^9}, {3.418656465722125*^9, 
  3.418656493909625*^9}, {3.418738500021*^9, 3.41873852792725*^9}}],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "s"], "(", "n", ")"}], "=", 
   RowBox[{
    RowBox[{"sin", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Alpha]", "0"], "+", 
       RowBox[{"n", " ", "\[Alpha]"}]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"x", " ", 
      RowBox[{"sin", "(", 
       RowBox[{
        SubscriptBox["\[Alpha]", "0"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "-", "2"}], ")"}], "\[Alpha]"}]}], ")"}]}], "+", 
     RowBox[{"y", " ", 
      RowBox[{"sin", "(", 
       RowBox[{
        SubscriptBox["\[Alpha]", "0"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "-", "1"}], ")"}], " ", "\[Alpha]"}]}], ")"}]}]}]}]}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "c"], "(", "n", ")"}], "=", 
   RowBox[{
    RowBox[{"cos", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Alpha]", "0"], "+", 
       RowBox[{"n", " ", "\[Alpha]"}]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"p", " ", 
      RowBox[{"cos", "(", 
       RowBox[{
        SubscriptBox["\[Alpha]", "0"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "-", "2"}], ")"}], "\[Alpha]"}]}], ")"}]}], "+", 
     RowBox[{"q", " ", 
      RowBox[{"cos", "(", 
       RowBox[{
        SubscriptBox["\[Alpha]", "0"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "-", "1"}], ")"}], " ", "\[Alpha]"}]}], ")"}]}]}]}]}], 
  TraditionalForm]}], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41865628242525*^9, 3.418656316503375*^9}, {
  3.4186564223315*^9, 3.4186564439565*^9}, {3.418656503815875*^9, 
  3.41865668598775*^9}, {3.418656969034625*^9, 3.418656999003375*^9}}],

Cell["\<\
Using the trigonometric formulae for expanding sine and cosine of sums we \
find\
\>", "Text",
 CellChangeTimes->{{3.418656125644*^9, 3.418656126878375*^9}, {
  3.418656693534625*^9, 3.418656734409625*^9}, {3.418656767753375*^9, 
  3.418656783409625*^9}, {3.418656835019*^9, 3.418656837159625*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"x", "=", 
   RowBox[{"p", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "   ", "and", " ", "y"}], "=", 
     RowBox[{"q", "=", 
      RowBox[{"2", 
       RowBox[{"cos", "(", "\[Alpha]", ")"}]}]}]}]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41865628242525*^9, 3.418656316503375*^9}, {
  3.4186564223315*^9, 3.4186564439565*^9}, {3.418656503815875*^9, 
  3.41865668598775*^9}, {3.41865684461275*^9, 3.418656869519*^9}}],

Cell[TextData[{
 "Again, this corresponds to a simple second order filter section with a \
complex pole pair. The trick is to load the correct initialization \
coefficients into ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "(", 
    RowBox[{"-", "1"}], ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "(", 
    RowBox[{"-", "2"}], ")"}], TraditionalForm]]],
 ". However, this is fairly straight forward"
}], "Text",
 CellChangeTimes->{{3.418656887034625*^9, 3.418656915597125*^9}, {
  3.418656948690875*^9, 3.41865695855025*^9}, {3.4186570032065*^9, 
  3.418657054534625*^9}, {3.418657088019*^9, 3.418657123472125*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "s"], "(", 
     RowBox[{"-", "1"}], ")"}], "=", 
    RowBox[{
     RowBox[{"sin", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Alpha]", "0"], "-", "\[Alpha]"}], ")"}], "     ", 
      "and", "   ", 
      RowBox[{
       SubscriptBox["y", "s"], "(", 
       RowBox[{"-", "2"}], ")"}]}], "=", 
     RowBox[{"sin", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Alpha]", "0"], "-", 
        RowBox[{"2", "\[Alpha]"}]}], ")"}]}]}]}], ",", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     SubscriptBox["y", "c"], "(", 
     RowBox[{"-", "1"}], ")"}], "=", 
    RowBox[{
     RowBox[{"cos", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Alpha]", "0"], "-", " ", "\[Alpha]"}], ")"}], "   ", 
      "and", "   ", 
      RowBox[{
       SubscriptBox["y", "c"], "(", 
       RowBox[{"-", "2"}], ")"}]}], "=", 
     RowBox[{"cos", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Alpha]", "0"], "-", " ", 
         RowBox[{"2", "\[Alpha]"}]}], ")"}], "."}]}]}]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41865628242525*^9, 3.418656316503375*^9}, {
  3.4186564223315*^9, 3.4186564439565*^9}, {3.418656503815875*^9, 
  3.41865668598775*^9}, {3.418656969034625*^9, 3.418656999003375*^9}, {
  3.41865713186275*^9, 3.41865719730025*^9}}],

Cell["\<\
Of course, if both sine and cosine functions are required the CORDIC \
(coordinate rotational digital computer) algorithm could be used as well. The \
CORDIC algorithm is not of the form of our second-order filter from above, \
but can be looked at as a two-input two-output IIR filter. Let's look at the \
following trigonometric equation\
\>", "Text",
 CellChangeTimes->{{3.418657250565875*^9, 3.418657296784625*^9}, {
   3.418657344644*^9, 3.418657506440875*^9}, 3.418668626222125*^9, {
   3.418668747722125*^9, 3.41866876242525*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    StyleBox["y",
     FontWeight->"Bold"], "(", "n", ")"}], "=", 
   RowBox[{
    RowBox[{"(", GridBox[{
       {
        RowBox[{"cos", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Alpha]", "0"], "+", 
           RowBox[{"n", " ", "\[Alpha]"}]}], ")"}]}]},
       {
        RowBox[{"sin", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Alpha]", "0"], "+", 
           RowBox[{"n", " ", "\[Alpha]"}]}], ")"}]}]}
      }], ")"}], "=", 
    RowBox[{
     RowBox[{"(", GridBox[{
        {
         RowBox[{"cos", "(", "\[Alpha]", ")"}], 
         RowBox[{"-", 
          RowBox[{"sin", "(", "\[Alpha]", ")"}]}]},
        {
         RowBox[{"sin", "(", "\[Alpha]", ")"}], 
         RowBox[{"cos", "(", "\[Alpha]", ")"}]}
       }], ")"}], 
     RowBox[{
      StyleBox["y",
       FontWeight->"Bold"], "(", 
      RowBox[{"n", "-", "1"}], ")"}]}]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41865628242525*^9, 3.418656316503375*^9}, {
  3.4186564223315*^9, 3.4186564439565*^9}, {3.418656503815875*^9, 
  3.41865668598775*^9}, {3.418656969034625*^9, 3.418656999003375*^9}, {
  3.41865713186275*^9, 3.41865719730025*^9}, {3.41865754817525*^9, 
  3.41865755686275*^9}, {3.418657622019*^9, 3.418657720753375*^9}, {
  3.4186578230815*^9, 3.41865786986275*^9}}],

Cell["Initializing it with", "Text",
 CellChangeTimes->{{3.4186579005815*^9, 3.418657904472125*^9}, {
  3.418668628253375*^9, 3.418668632144*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    StyleBox["y",
     FontWeight->"Bold"], "(", 
    RowBox[{"-", "1"}], ")"}], "=", 
   RowBox[{"(", GridBox[{
      {
       RowBox[{"cos", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Alpha]", "0"], "-", " ", "\[Alpha]"}], ")"}]}]},
      {
       RowBox[{"sin", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Alpha]", "0"], "-", " ", "\[Alpha]"}], ")"}]}]}
     }], ")"}]}], TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41865628242525*^9, 3.418656316503375*^9}, {
  3.4186564223315*^9, 3.4186564439565*^9}, {3.418656503815875*^9, 
  3.41865668598775*^9}, {3.418656969034625*^9, 3.418656999003375*^9}, {
  3.41865713186275*^9, 3.41865719730025*^9}, {3.41865754817525*^9, 
  3.41865755686275*^9}, {3.418657622019*^9, 3.418657720753375*^9}, {
  3.4186578230815*^9, 3.41865786986275*^9}, {3.418668642003375*^9, 
  3.4186686540815*^9}}],

Cell["\<\
will lead to a simultanous generation of sine and cosine functions through \
coordinate rotation. This algorithm can be expanded to include an input \
series\
\>", "Text",
 CellChangeTimes->{{3.41866866086275*^9, 3.41866872017525*^9}, {
  3.418668769190875*^9, 3.4186687932065*^9}, {3.418740465755375*^9, 
  3.418740498396*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    StyleBox["y",
     FontWeight->"Bold"], "(", "n", ")"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", GridBox[{
        {
         RowBox[{"cos", "(", "\[Alpha]", ")"}], 
         RowBox[{"-", 
          RowBox[{"sin", "(", "\[Alpha]", ")"}]}]},
        {
         RowBox[{"sin", "(", "\[Alpha]", ")"}], 
         RowBox[{"cos", "(", "\[Alpha]", ")"}]}
       }], ")"}], 
     RowBox[{
      StyleBox["y",
       FontWeight->"Bold"], "(", 
      RowBox[{"n", "-", "1"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      StyleBox["x",
       FontWeight->"Bold"], "(", "n", ")"}], "."}]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41865628242525*^9, 3.418656316503375*^9}, {
   3.4186564223315*^9, 3.4186564439565*^9}, {3.418656503815875*^9, 
   3.41865668598775*^9}, {3.418656969034625*^9, 3.418656999003375*^9}, {
   3.41865713186275*^9, 3.41865719730025*^9}, {3.41865754817525*^9, 
   3.41865755686275*^9}, {3.418657622019*^9, 3.418657720753375*^9}, {
   3.4186578230815*^9, 3.41865786986275*^9}, {3.418740504411625*^9, 
   3.418740507942875*^9}, {3.4187406237085*^9, 3.418740624161625*^9}, 
   3.41874068861475*^9}],

Cell[TextData[{
 "This later algorithm can be initialize every ",
 Cell[BoxData[
  FormBox["M", TraditionalForm]]],
 " samples by setting all history values to zero. The following time series \
can be fed into the algorithm to generate cosine and sine wave outputs of \
amplitude ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.418740519505375*^9, 3.41874061048975*^9}, {
  3.418740711942875*^9, 3.418740721724125*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", "(", "k", ")"}], "=", 
   RowBox[{"A", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"l", "=", 
       RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], " ", 
     RowBox[{
      RowBox[{"(", GridBox[{
         {
          SubscriptBox["\[Delta]", 
           RowBox[{"k", ",", 
            RowBox[{"l", " ", "M"}]}]]},
         {"0"}
        }], ")"}], "."}]}]}]}], TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.418655776128375*^9, 3.418655776878375*^9}, {
  3.41865583430025*^9, 3.418655901909625*^9}, {3.4187406582085*^9, 
  3.41874073386475*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Demodulation", "Section",
 CellChangeTimes->{{3.41864878967525*^9, 3.418648848519*^9}}],

Cell["\<\
Demodulating a signal with a sine or cosine function and then taking an \
average is very similar in concept to computing a discrete Fourier \
coefficient. The descrite Fourier transform from above will compute the \
cosine and sine terms on time series of fixed length. By virtue of summing \
over all samples an average is formed. The disadvantage of this algorithm is \
that it needs to be restarted for every new time series. We prefer to have an \
algoithm which works continuously. We can write a demodulation as\
\>", "Text",
 CellChangeTimes->{{3.418668940190875*^9, 3.41866922623775*^9}, {
  3.418669770253375*^9, 3.418669776815875*^9}, {3.41867181505025*^9, 
  3.418671899472125*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"u", "(", "k", ")"}], "=", 
   RowBox[{
    SuperscriptBox["W", 
     RowBox[{"-", "k"}]], 
    RowBox[{
     RowBox[{"x", "(", "k", ")"}], "."}]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864622730025*^9, 
   3.418646228847125*^9}, {3.418646623347125*^9, 3.418646632534625*^9}, 
   3.41864669961275*^9, {3.41864675748775*^9, 3.41864678348775*^9}, {
   3.41864690955025*^9, 3.4186469540815*^9}, {3.418646994284625*^9, 
   3.418647091972125*^9}, {3.418647245628375*^9, 3.418647254097125*^9}, {
   3.41865297186275*^9, 3.418652979003375*^9}, {3.41865350855025*^9, 
   3.418653520253375*^9}, {3.418669331753375*^9, 3.41866937961275*^9}, {
   3.41866948373775*^9, 3.418669526409625*^9}, 3.418669787628375*^9, {
   3.4186698772065*^9, 3.418669887644*^9}}],

Cell["Then, we apply a single pole filter with exponential decay", "Text",
 CellChangeTimes->{{3.418669792519*^9, 3.418669817534625*^9}, 
   3.41867168948775*^9, {3.418738844036625*^9, 3.41873884455225*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"y", "(", "n", ")"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"y", "(", 
       RowBox[{"n", "-", "1"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "r"}], ")"}], 
      RowBox[{"u", "(", "n", ")"}]}]}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "r"}], ")"}], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", 
        RowBox[{"-", "\[Infinity]"}]}], "n"], 
      RowBox[{
       SuperscriptBox["r", 
        RowBox[{"n", "-", "k"}]], 
       RowBox[{
        RowBox[{"u", "(", "k", ")"}], "."}]}]}]}]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864622730025*^9, 
   3.418646228847125*^9}, {3.418646623347125*^9, 3.418646632534625*^9}, 
   3.41864669961275*^9, {3.41864675748775*^9, 3.41864678348775*^9}, {
   3.41864690955025*^9, 3.4186469540815*^9}, {3.418646994284625*^9, 
   3.418647091972125*^9}, {3.418647245628375*^9, 3.418647254097125*^9}, {
   3.41865297186275*^9, 3.418652979003375*^9}, {3.41865350855025*^9, 
   3.418653520253375*^9}, {3.418669331753375*^9, 3.41866937961275*^9}, {
   3.41866948373775*^9, 3.418669526409625*^9}, {3.41866956461275*^9, 
   3.418669704128375*^9}, 3.418669825644*^9, {3.41866986261275*^9, 
   3.418669862847125*^9}}],

Cell["Combining the two equations yields", "Text",
 CellChangeTimes->{{3.418669823628375*^9, 3.41866983811275*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"y", "(", "n", ")"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["W", 
      RowBox[{"-", "n"}]], "(", 
     RowBox[{"1", "-", "r"}], ")"}], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", 
       RowBox[{"-", "\[Infinity]"}]}], "n"], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"r", " "}], 
       RowBox[{"n", "-", "k"}]], 
      SuperscriptBox["W", 
       RowBox[{"n", "-", "k"}]], 
      RowBox[{
       RowBox[{"x", "(", "k", ")"}], "."}]}]}]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
   3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
   3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
   3.418646119019*^9, 3.41864615461275*^9}, {3.41864622730025*^9, 
   3.418646228847125*^9}, {3.418646623347125*^9, 3.418646632534625*^9}, 
   3.41864669961275*^9, {3.41864675748775*^9, 3.41864678348775*^9}, {
   3.41864690955025*^9, 3.4186469540815*^9}, {3.418646994284625*^9, 
   3.418647091972125*^9}, {3.418647245628375*^9, 3.418647254097125*^9}, {
   3.41865297186275*^9, 3.418652979003375*^9}, {3.41865350855025*^9, 
   3.418653520253375*^9}, {3.418669331753375*^9, 3.41866937961275*^9}, {
   3.41866974736275*^9, 3.418669755190875*^9}, 3.41866984330025*^9, {
   3.418669919784625*^9, 3.41866993167525*^9}}],

Cell[TextData[{
 "Unfortunately, this algorithm generates an output series which is not \
really demodulated. An adidional rotation by ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["W", "n"], TraditionalForm]]],
 " would be required. If we also require a decimation by ",
 Cell[BoxData[
  FormBox["M", TraditionalForm]]],
 " and if we can adjust the demodulation frequency so that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["W", "M"], "=", "1"}], TraditionalForm]]],
 ", then the series ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "(", 
    RowBox[{"k", " ", "M"}], ")"}], TraditionalForm]]],
 " will be the demodulated and filterd complex output. Only a single pole \
filter can be implemented in a straight forward manner, so."
}], "Text",
 CellChangeTimes->{{3.418737303567875*^9, 3.418737339146*^9}, {
  3.418737394646*^9, 3.418737442271*^9}, {3.418737485771*^9, 
  3.418737625942875*^9}, {3.41873770367725*^9, 3.418737751692875*^9}, {
  3.418738590974125*^9, 3.418738591317875*^9}}],

Cell["\<\
A more flexible approach is to used a cosine/sine generator and multiple the \
input time series by both of them to form a in-phase and a quad-phase signal. \
Then, filters of any order can be applied to each phase independently. These \
two time series can be thought of as a complex time series. They can easily \
be combined to adjust the demodulation phase, or to compute the absolute \
value and phase angle.\
\>", "Text",
 CellChangeTimes->{{3.418737754005375*^9, 3.418737929567875*^9}, {
  3.418737973380375*^9, 3.418737985942875*^9}, {3.418738703317875*^9, 
  3.418738781536625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equations", "Section",
 CellChangeTimes->{{3.418645443534625*^9, 3.41864544548775*^9}}],

Cell[TextData[{
 "GoertzelBasic[l, w] takes a time series l and applies the basic Gortzel \
algorithm without the complex zero. It can be used to generate a sine wave. \
",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 " denotes the angular frequency ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Pi]", " ", 
    RowBox[{"f", "/", 
     SubscriptBox["f", "N"]}]}], TraditionalForm]],
  CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
    3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
    3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
    3.418646119019*^9, 3.41864615461275*^9}, {3.41864622730025*^9, 
    3.418646228847125*^9}, {3.418646623347125*^9, 3.418646632534625*^9}, 
    3.41864669961275*^9, {3.41864675748775*^9, 3.41864678348775*^9}, {
    3.41864690955025*^9, 3.4186469540815*^9}, {3.418646994284625*^9, 
    3.418647091972125*^9}, {3.41865460423775*^9, 3.418654622753375*^9}, {
    3.418654659472125*^9, 3.4186546883315*^9}}],
 "."
}], "Text",
 CellChangeTimes->{{3.418738929255375*^9, 3.418739022599125*^9}, {
  3.4187391318335*^9, 3.418739132521*^9}, {3.41873928967725*^9, 
  3.418739326849125*^9}, {3.41873945080225*^9, 3.41873945111475*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GoertzelBasic", "[", 
   RowBox[{"l_List", ",", "w_"}], "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"old", "=", "0"}], ",", " ", 
      RowBox[{"oldold", "=", "0"}], ",", "i", ",", "new", ",", 
      RowBox[{"res", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "<=", 
        RowBox[{"Length", "[", "l", "]"}]}], ",", 
       RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"new", "=", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", "w", "]"}], "old"}], "-", "oldold", "+", 
          RowBox[{
          "l", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"res", ",", "new"}], "]"}], ";", " ", "\[IndentingNewLine]", 
        
        RowBox[{"oldold", "=", "old"}], ";", "\[IndentingNewLine]", 
        RowBox[{"old", "=", "new"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", "res"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4184943419418697`*^9, 3.418494347627902*^9}, {
   3.418494390139998*^9, 3.41849460869979*^9}, {3.4184946400591183`*^9, 
   3.41849467769971*^9}, {3.418494952085998*^9, 3.4184949552187977`*^9}, {
   3.418494991011038*^9, 3.418494992796734*^9}, {3.4184954214107656`*^9, 
   3.4184954265642223`*^9}, {3.418495474731022*^9, 3.418495483565518*^9}, 
   3.418495587417838*^9, {3.41873900123975*^9, 3.41873900361475*^9}, {
   3.418739056146*^9, 3.418739064880375*^9}}],

Cell[TextData[{
 "Goertzel[l, w] takes a time series l and applies the Gortzel algorithm. Its \
output is complex and it can be used to compute a discrete Fourier \
coefficent. ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 " denotes the angular frequency ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Pi]", " ", 
    RowBox[{"f", "/", 
     SubscriptBox["f", "N"]}]}], TraditionalForm]],
  CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
    3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
    3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
    3.418646119019*^9, 3.41864615461275*^9}, {3.41864622730025*^9, 
    3.418646228847125*^9}, {3.418646623347125*^9, 3.418646632534625*^9}, 
    3.41864669961275*^9, {3.41864675748775*^9, 3.41864678348775*^9}, {
    3.41864690955025*^9, 3.4186469540815*^9}, {3.418646994284625*^9, 
    3.418647091972125*^9}, {3.41865460423775*^9, 3.418654622753375*^9}, {
    3.418654659472125*^9, 3.4186546883315*^9}}],
 ".\nGoertzel[l, w, r] takes a time series l and applies the Gortzel \
algorithm incuding an additional pole. Its output is complex and it can be \
used to form a demodulated filter signal. ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 " denotes the angular frequency ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Pi]", " ", 
    RowBox[{"f", "/", 
     SubscriptBox["f", "N"]}]}], TraditionalForm]],
  CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
    3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
    3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
    3.418646119019*^9, 3.41864615461275*^9}, {3.41864622730025*^9, 
    3.418646228847125*^9}, {3.418646623347125*^9, 3.418646632534625*^9}, 
    3.41864669961275*^9, {3.41864675748775*^9, 3.41864678348775*^9}, {
    3.41864690955025*^9, 3.4186469540815*^9}, {3.418646994284625*^9, 
    3.418647091972125*^9}, {3.41865460423775*^9, 3.418654622753375*^9}, {
    3.418654659472125*^9, 3.4186546883315*^9}}],
 ". ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]]],
 " denotes the filter coefficient of the averaging pole."
}], "Text",
 CellChangeTimes->{{3.418739138161625*^9, 3.418739204646*^9}, {
  3.418739261317875*^9, 3.418739263630375*^9}, {3.418739340505375*^9, 
  3.4187394469585*^9}, {3.41873947836475*^9, 3.418739506505375*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Goertzel", "[", 
   RowBox[{"l_List", ",", "w_"}], "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"old", "=", "0"}], ",", " ", 
      RowBox[{"oldold", "=", "0"}], ",", "i", ",", "new", ",", 
      RowBox[{"res", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "<=", 
        RowBox[{"Length", "[", "l", "]"}]}], ",", 
       RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"new", "=", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", "w", "]"}], "old"}], "-", "oldold", "+", 
          RowBox[{
          "l", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"res", ",", 
          RowBox[{"new", "-", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", "w"}]], "old"}]}]}], "]"}],
         ";", " ", "\[IndentingNewLine]", 
        RowBox[{"oldold", "=", "old"}], ";", "\[IndentingNewLine]", 
        RowBox[{"old", "=", "new"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", "res"}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Goertzel", "[", 
   RowBox[{"l_List", ",", "w_", ",", "r_"}], "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"old", "=", "0"}], ",", " ", 
      RowBox[{"oldold", "=", "0"}], ",", "i", ",", "new", ",", 
      RowBox[{"res", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "<=", 
        RowBox[{"Length", "[", "l", "]"}]}], ",", 
       RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"new", "=", 
         RowBox[{
          RowBox[{"2", " ", "r", " ", 
           RowBox[{"Cos", "[", "w", "]"}], "old"}], "-", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", "oldold"}], "+", 
          RowBox[{
          "l", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"res", ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "r"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"new", "-", 
             RowBox[{"r", " ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", "w"}]], "old"}]}], 
            ")"}]}]}], "]"}], ";", " ", "\[IndentingNewLine]", 
        RowBox[{"oldold", "=", "old"}], ";", "\[IndentingNewLine]", 
        RowBox[{"old", "=", "new"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", "res"}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.41873907380225*^9, 3.418739074036625*^9}}],

Cell[TextData[{
 "Cordic[l, w] takes a 2-dimensional time series and applies the cordic \
algorithm using a simple rotation with each step. ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 " denotes the angular frequency ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Pi]", " ", 
    RowBox[{"f", "/", 
     SubscriptBox["f", "N"]}]}], TraditionalForm]],
  CellChangeTimes->{{3.41864562323775*^9, 3.418645673440875*^9}, {
    3.418645753815875*^9, 3.418645757597125*^9}, {3.418645796503375*^9, 
    3.418645811394*^9}, {3.418645884659625*^9, 3.418645954190875*^9}, {
    3.418646119019*^9, 3.41864615461275*^9}, {3.41864622730025*^9, 
    3.418646228847125*^9}, {3.418646623347125*^9, 3.418646632534625*^9}, 
    3.41864669961275*^9, {3.41864675748775*^9, 3.41864678348775*^9}, {
    3.41864690955025*^9, 3.4186469540815*^9}, {3.418646994284625*^9, 
    3.418647091972125*^9}, {3.41865460423775*^9, 3.418654622753375*^9}, {
    3.418654659472125*^9, 3.4186546883315*^9}}],
 ". The output is a two-dimensional series which can be used to generate a \
cosine and sine wave simultanously."
}], "Text",
 CellChangeTimes->{{3.418740021271*^9, 3.418740134130375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cordic", "[", 
   RowBox[{"l_List", ",", "w_"}], "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"old", "=", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], ",", "i", ",", "new", ",", 
      RowBox[{"res", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "<=", 
        RowBox[{"Length", "[", "l", "]"}]}], ",", 
       RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"new", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"(", GridBox[{
              {
               RowBox[{"Cos", "[", "w", "]"}], 
               RowBox[{"-", 
                RowBox[{"Sin", "[", "w", "]"}]}]},
              {
               RowBox[{"Sin", "[", "w", "]"}], 
               RowBox[{"Cos", "[", "w", "]"}]}
             }], ")"}], ".", "old"}], "+", 
          RowBox[{
          "l", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"res", ",", "new"}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"old", "=", "new"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", "res"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.418739847474125*^9, 3.418740016786625*^9}, {
  3.418740216099125*^9, 3.418740217911625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tests", "Section",
 CellChangeTimes->{{3.4187389063335*^9, 3.41873890798975*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nn", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"np", "=", "100."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rr", "=", 
   RowBox[{"1", "-", "0.001"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mod", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Exp", "[", " ", 
      RowBox[{"\[ImaginaryI]", 
       FractionBox[
        RowBox[{"2", "\[Pi]", " ", "i"}], "np"]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "nn"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"uvec", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Exp", "[", " ", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", 
        FractionBox[
         RowBox[{"2", "\[Pi]", " ", "i"}], "np"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "nn"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"Goertzel", "[", 
    RowBox[{
     RowBox[{"Re", "[", "uvec", "]"}], ",", 
     FractionBox[
      RowBox[{"2", "\[Pi]"}], "np"], ",", "rr"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h", "=", 
   RowBox[{"g", " ", 
    RowBox[{"mod", "\[Conjugate]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gg", "=", 
   RowBox[{"Pick", "[", 
    RowBox[{"g", ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"i", ",", "100"}], "]"}], "\[Equal]", "0"}], ",", "True", 
         ",", "False"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "nn"}], "}"}]}], "]"}]}], "]"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.418494625162654*^9, 3.418494633307934*^9}, {
   3.418494701461998*^9, 3.418494705096046*^9}, {3.418494744334366*^9, 
   3.41849481601283*^9}, {3.418494848781918*^9, 3.4184948502856617`*^9}, 
   3.418494908837694*^9, {3.4184949659016457`*^9, 3.418494966637854*^9}, {
   3.418495034979886*^9, 3.418495193859838*^9}, 3.4184953796505423`*^9, {
   3.418673358144*^9, 3.418673393519*^9}, {3.4186734372065*^9, 
   3.41867351736275*^9}, {3.41867675861275*^9, 3.4186768270815*^9}, {
   3.418676988784625*^9, 3.418677009909625*^9}, {3.418677048065875*^9, 
   3.418677109909625*^9}, {3.418677162003375*^9, 3.418677196003375*^9}, {
   3.41867722830025*^9, 3.41867726198775*^9}, {3.41867729617525*^9, 
   3.418677337003375*^9}, {3.418677579378375*^9, 3.418677580394*^9}, 
   3.41867761667525*^9, {3.4186779812065*^9, 3.41867800592525*^9}, {
   3.418678119065875*^9, 3.418678121972125*^9}, {3.41867856505025*^9, 
   3.4186785729565*^9}, {3.418678634784625*^9, 3.41867865530025*^9}, {
   3.41873033223975*^9, 3.41873037661475*^9}, {3.418730435630375*^9, 
   3.418730485755375*^9}, 3.41873054780225*^9, {3.41873060017725*^9, 
   3.418730620021*^9}, {3.418731242567875*^9, 3.41873125155225*^9}, 
   3.418731317067875*^9, {3.418731354255375*^9, 3.418731360349125*^9}, {
   3.41873142611475*^9, 3.418731452474125*^9}, {3.418731485255375*^9, 
   3.41873148617725*^9}, {3.41873154136475*^9, 3.4187315797085*^9}, {
   3.418731646021*^9, 3.418731715567875*^9}, {3.41873176486475*^9, 
   3.4187317958335*^9}, {3.418731916505375*^9, 3.4187319618335*^9}, {
   3.418732013021*^9, 3.418732044599125*^9}, {3.418732117130375*^9, 
   3.418732129771*^9}, {3.418732167724125*^9, 3.418732170036625*^9}, {
   3.418732262224125*^9, 3.4187323454585*^9}, {3.418732450505375*^9, 
   3.418732450771*^9}, {3.41873248886475*^9, 3.418732523911625*^9}, {
   3.41873259030225*^9, 3.41873270336475*^9}, 3.418732739396*^9, {
   3.41873278030225*^9, 3.41873278798975*^9}, {3.418732854380375*^9, 
   3.41873285586475*^9}, {3.41873291086475*^9, 3.41873292936475*^9}, {
   3.418732969771*^9, 3.418732975942875*^9}, {3.418733283130375*^9, 
   3.418733346896*^9}, {3.41873338286475*^9, 3.418733428380375*^9}, {
   3.418735140317875*^9, 3.418735188067875*^9}, {3.418735239771*^9, 
   3.418735244146*^9}, {3.418735300442875*^9, 3.418735323067875*^9}, {
   3.41873535505225*^9, 3.418735363192875*^9}, {3.418735578036625*^9, 
   3.4187356038335*^9}, {3.41874077123975*^9, 3.4187407718335*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Re", "[", "h", "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"9000", ",", "10000"}], "}"}], ",", "Automatic"}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.418494808917038*^9, 3.4184948277295017`*^9}, {
   3.418494871134446*^9, 3.4184948873936777`*^9}, 3.418494974877118*^9, {
   3.4184962525269423`*^9, 3.418496259481758*^9}, {3.41867347530025*^9, 
   3.41867348567525*^9}, {3.418676722972125*^9, 3.41867679592525*^9}, {
   3.418677147034625*^9, 3.418677181394*^9}, {3.41867723573775*^9, 
   3.418677235972125*^9}, {3.418677983753375*^9, 3.418677983972125*^9}, {
   3.418730463817875*^9, 3.418730515286625*^9}, {3.41873055548975*^9, 
   3.418730596567875*^9}, {3.418731264224125*^9, 3.418731277380375*^9}, {
   3.4187313257085*^9, 3.41873134642725*^9}, {3.41873151461475*^9, 
   3.418731527942875*^9}, {3.418731632271*^9, 3.418731662442875*^9}, {
   3.41873193292725*^9, 3.418731937271*^9}, {3.418731973880375*^9, 
   3.418731977317875*^9}, {3.418732226521*^9, 3.418732230599125*^9}, 
   3.41873231055225*^9, {3.418732364286625*^9, 3.418732457849125*^9}, {
   3.41873252642725*^9, 3.418732531505375*^9}, {3.418732713192875*^9, 
   3.418732754661625*^9}, {3.41873279998975*^9, 3.418732800192875*^9}, {
   3.418732868755375*^9, 3.4187328730835*^9}, {3.41873292117725*^9, 
   3.41873295480225*^9}, {3.418732986849125*^9, 3.418733024896*^9}, {
   3.418733055817875*^9, 3.41873309261475*^9}, {3.4187332967085*^9, 
   3.4187333597085*^9}, {3.418733420630375*^9, 3.41873343630225*^9}, 
   3.4187351679585*^9}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJw81HlcjO37PvCRKCTZQyqEEEII4SBLCCGUQippU2nXOu17TdM0My0IIQ+R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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  Frame->True,
  GridLines->Automatic,
  PlotRange->{{9000, 10000}, Automatic},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.418494828215086*^9, {3.418494970193582*^9, 3.418494997605582*^9}, {
   3.418495038958542*^9, 3.418495132018366*^9}, {3.418495162798126*^9, 
   3.418495195990142*^9}, 3.4184953829713097`*^9, {3.4184962339807663`*^9, 
   3.418496259873358*^9}, 3.4184963290299177`*^9, {3.418673486378375*^9, 
   3.41867352380025*^9}, 3.41867357511275*^9, {3.418676724347125*^9, 
   3.418676796409625*^9}, 3.418676829409625*^9, {3.418677147565875*^9, 
   3.41867719948775*^9}, {3.418677231315875*^9, 3.418677265534625*^9}, {
   3.418677298972125*^9, 3.418677308034625*^9}, {3.418677567690875*^9, 
   3.418677584847125*^9}, 3.418677621019*^9, {3.418677976394*^9, 
   3.41867800830025*^9}, 3.418678580909625*^9, {3.418678652019*^9, 
   3.4186786613315*^9}, {3.418730347130375*^9, 3.41873037905225*^9}, {
   3.4187304393335*^9, 3.418730516067875*^9}, {3.418730551474125*^9, 
   3.41873062198975*^9}, {3.418731264880375*^9, 3.41873127792725*^9}, {
   3.418731321474125*^9, 3.418731362692875*^9}, {3.418731430067875*^9, 
   3.418731455755375*^9}, {3.418731489849125*^9, 3.418731583505375*^9}, {
   3.418731633255375*^9, 3.418731725021*^9}, {3.41873177598975*^9, 
   3.41873179905225*^9}, {3.418731922521*^9, 3.418731977771*^9}, {
   3.418732019630375*^9, 3.4187320482085*^9}, {3.418732135349125*^9, 
   3.418732177255375*^9}, {3.418732227442875*^9, 3.4187322310835*^9}, {
   3.41873227030225*^9, 3.4187323652085*^9}, {3.418732412505375*^9, 
   3.418732458271*^9}, {3.418732527692875*^9, 3.418732531911625*^9}, {
   3.418732709880375*^9, 3.418732755349125*^9}, {3.4187327944585*^9, 
   3.418732800630375*^9}, {3.418732860786625*^9, 3.418732873567875*^9}, {
   3.418732917536625*^9, 3.418733025630375*^9}, {3.418733056817875*^9, 
   3.41873309336475*^9}, {3.418733287661625*^9, 3.418733360146*^9}, {
   3.418733395536625*^9, 3.418733436786625*^9}, {3.418735177755375*^9, 
   3.418735192771*^9}, {3.4187352513335*^9, 3.418735263724125*^9}, {
   3.418735313224125*^9, 3.418735377442875*^9}, {3.418735598474125*^9, 
   3.4187356087085*^9}, 3.41874077586475*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"uvec", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"i", "\[Equal]", "2"}], ",", 
       RowBox[{"Sin", "[", "\[Omega]", "]"}], ",", "0"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "10"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"g", "=", 
  RowBox[{
   RowBox[{"GoertzelBasic", "[", 
    RowBox[{"uvec", ",", "\[Omega]"}], "]"}], "//", 
   "TrigReduce"}]}]}], "Input",
 CellChangeTimes->{{3.418494625162654*^9, 3.418494633307934*^9}, {
   3.418494701461998*^9, 3.418494705096046*^9}, {3.418494744334366*^9, 
   3.41849481601283*^9}, {3.418494848781918*^9, 3.4184948502856617`*^9}, 
   3.418494908837694*^9, {3.4184949659016457`*^9, 3.418494966637854*^9}, {
   3.418495034979886*^9, 3.418495193859838*^9}, {3.4184952426531982`*^9, 
   3.41849526690107*^9}, 3.418495393481854*^9, {3.418495500780254*^9, 
   3.418495536462846*^9}, 3.4187390324585*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"Sin", "[", "\[Omega]", "]"}], ",", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Sin", "[", 
    RowBox[{"3", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Sin", "[", 
    RowBox[{"4", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Sin", "[", 
    RowBox[{"5", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Sin", "[", 
    RowBox[{"6", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Sin", "[", 
    RowBox[{"7", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Sin", "[", 
    RowBox[{"8", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Sin", "[", 
    RowBox[{"9", " ", "\[Omega]"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.418495257925598*^9, 3.418495267339662*^9}, {
   3.418495384193102*^9, 3.4184953943433743`*^9}, {3.4184955059650383`*^9, 
   3.4184955267355022`*^9}, 3.418495955365198*^9, {3.418739035442875*^9, 
   3.418739046880375*^9}, 3.41873951355225*^9, 3.41874079361475*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"uvec", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"i", "\[Equal]", "1"}], ",", "1", ",", "0"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "10"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"gC", "=", 
   RowBox[{
    RowBox[{"Goertzel", "[", 
     RowBox[{"uvec", ",", "\[Omega]"}], "]"}], "//", 
    "TrigReduce"}]}]}]], "Input",
 CellChangeTimes->{{3.41849554556363*^9, 3.418495551719582*^9}, {
   3.418495634488158*^9, 3.41849567400843*^9}, {3.4184960385723658`*^9, 
   3.418496047923774*^9}, {3.418496600628014*^9, 3.418496603729486*^9}, 
   3.4187390519585*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]], ",", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]"}]], ",", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"3", " ", "\[Omega]"}], "]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"3", " ", "\[Omega]"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"4", " ", "\[Omega]"}], "]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"4", " ", "\[Omega]"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"5", " ", "\[Omega]"}], "]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"5", " ", "\[Omega]"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"6", " ", "\[Omega]"}], "]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"6", " ", "\[Omega]"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"7", " ", "\[Omega]"}], "]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"7", " ", "\[Omega]"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"8", " ", "\[Omega]"}], "]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"8", " ", "\[Omega]"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"9", " ", "\[Omega]"}], "]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"9", " ", "\[Omega]"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.418495257925598*^9, 3.418495267339662*^9}, {
   3.418495384193102*^9, 3.4184953943433743`*^9}, {3.4184955059650383`*^9, 
   3.418495553285982*^9}, 3.4184955910048943`*^9, {3.418495635490654*^9, 
   3.418495674447022*^9}, {3.418496039590526*^9, 3.418496048816622*^9}, {
   3.418496601066606*^9, 3.4184966043560457`*^9}, {3.418731840255375*^9, 
   3.418731849521*^9}, 3.418739514817875*^9, 3.418740794396*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"uvec", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"i", "\[Equal]", "1"}], ",", "1", ",", "0"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "10"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"g", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{"Goertzel", "[", 
      RowBox[{"uvec", ",", "\[Omega]"}], "]"}], "]"}], "//", 
    "ComplexExpand"}], "//", "TrigReduce"}]}]}], "Input",
 CellChangeTimes->{{3.418495943476222*^9, 3.418495945011294*^9}, {
   3.4184961955883017`*^9, 3.418496210845038*^9}, {3.418496298908046*^9, 
   3.4184963048290377`*^9}, {3.4184964710710697`*^9, 3.4184965009893103`*^9}, 
   3.418496550816494*^9, {3.418496607253886*^9, 3.41849665731603*^9}, {
   3.41849674237155*^9, 3.418497014502222*^9}, {3.41849705588651*^9, 
   3.418497085945726*^9}, {3.418497174478654*^9, 3.418497175841422*^9}, {
   3.418739608005375*^9, 3.418739630161625*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"Cos", "[", "\[Omega]", "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"3", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"4", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"5", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"6", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"7", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"8", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"9", " ", "\[Omega]"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.418497058753022*^9, 3.4184970863686543`*^9}, 
   3.41849717634267*^9, 3.4187396310835*^9, 3.418740795271*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"uvec", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"i", "\[Equal]", "2"}], ",", 
       RowBox[{"2", 
        RowBox[{"Cos", "[", "\[Omega]", "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"i", "\[Equal]", "3"}], ",", 
         RowBox[{"-", "1"}], ",", "0"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "10"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"g", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{"Goertzel", "[", 
      RowBox[{"uvec", ",", "\[Omega]"}], "]"}], "]"}], "//", 
    "ComplexExpand"}], "//", "TrigReduce"}]}]}], "Input",
 CellChangeTimes->{{3.418495943476222*^9, 3.418495945011294*^9}, {
   3.4184961955883017`*^9, 3.418496210845038*^9}, {3.418496298908046*^9, 
   3.4184963048290377`*^9}, {3.4184964710710697`*^9, 3.4184965009893103`*^9}, 
   3.418496550816494*^9, {3.418496607253886*^9, 3.41849665731603*^9}, {
   3.41849674237155*^9, 3.418497014502222*^9}, {3.41873952261475*^9, 
   3.418739596146*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"2", " ", 
    RowBox[{"Cos", "[", "\[Omega]", "]"}]}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"3", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"4", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"5", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"6", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"7", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"8", " ", "\[Omega]"}], "]"}], ",", 
   RowBox[{"Cos", "[", 
    RowBox[{"9", " ", "\[Omega]"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.418496772618734*^9, 3.418496871004318*^9}, {
   3.418496902943214*^9, 3.418497014940814*^9}, {3.418739516474125*^9, 
   3.4187395404585*^9}, {3.4187395790835*^9, 3.418739597021*^9}, 
   3.41874079623975*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"vvec", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"i", "\[Equal]", "1"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "10"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Cordic", "[", 
   RowBox[{"vvec", ",", "\[Omega]"}], "]"}], "//", "TrigReduce"}]}], "Input",
 CellChangeTimes->{{3.418740147255375*^9, 3.418740195880375*^9}, {
  3.4187403908335*^9, 3.418740412817875*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", "\[Omega]", "]"}], ",", 
     RowBox[{"Sin", "[", "\[Omega]", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "\[Omega]"}], "]"}], ",", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Omega]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", "\[Omega]"}], "]"}], ",", 
     RowBox[{"Sin", "[", 
      RowBox[{"3", " ", "\[Omega]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"4", " ", "\[Omega]"}], "]"}], ",", 
     RowBox[{"Sin", "[", 
      RowBox[{"4", " ", "\[Omega]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"5", " ", "\[Omega]"}], "]"}], ",", 
     RowBox[{"Sin", "[", 
      RowBox[{"5", " ", "\[Omega]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"6", " ", "\[Omega]"}], "]"}], ",", 
     RowBox[{"Sin", "[", 
      RowBox[{"6", " ", "\[Omega]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"7", " ", "\[Omega]"}], "]"}], ",", 
     RowBox[{"Sin", "[", 
      RowBox[{"7", " ", "\[Omega]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"8", " ", "\[Omega]"}], "]"}], ",", 
     RowBox[{"Sin", "[", 
      RowBox[{"8", " ", "\[Omega]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"9", " ", "\[Omega]"}], "]"}], ",", 
     RowBox[{"Sin", "[", 
      RowBox[{"9", " ", "\[Omega]"}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.41874019742725*^9, 3.41874022367725*^9}, {
   3.418740402380375*^9, 3.41874041342725*^9}, 3.418740798255375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"prm", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "\[Rule]", "960"}], ",", 
    RowBox[{"fN", "\[Rule]", 
     SuperscriptBox["2", "19"]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"2", "\[Pi]", " ", "f"}], "fN"], "]"}]}], "/.", "prm"}], ",", 
   "20"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sin", "[", 
     FractionBox[
      RowBox[{"2", "\[Pi]", " ", "f"}], "fN"], "]"}], "/.", "prm"}], ",", 
   "20"}], "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.42720074965625*^9, 3.427200810953125*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f", "\[Rule]", "960"}], ",", 
   RowBox[{"fN", "\[Rule]", "524288"}]}], "}"}]], "Output",
 CellChangeTimes->{3.427200812453125*^9}],

Cell[BoxData["1.99986763975047194343619476135081260263`20."], "Output",
 CellChangeTimes->{3.4272008125*^9}],

Cell[BoxData["0.01150460211042271472157869254768855879`20."], "Output",
 CellChangeTimes->{3.4272008125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"prm", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "\[Rule]", "961"}], ",", 
    RowBox[{"fN", "\[Rule]", 
     SuperscriptBox["2", "19"]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"2", "\[Pi]", " ", "f"}], "fN"], "]"}]}], "/.", "prm"}], ",", 
   "20"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sin", "[", 
     FractionBox[
      RowBox[{"2", "\[Pi]", " ", "f"}], "fN"], "]"}], "/.", "prm"}], ",", 
   "20"}], "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.42720074965625*^9, 3.42720082196875*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f", "\[Rule]", "961"}], ",", 
   RowBox[{"fN", "\[Rule]", "524288"}]}], "}"}]], "Output",
 CellChangeTimes->{3.427200822671875*^9}],

Cell[BoxData["1.999867363859381532463429486061742952`20."], "Output",
 CellChangeTimes->{3.427200822703125*^9}],

Cell[BoxData["0.01151658554138413006113613626683339292`20."], "Output",
 CellChangeTimes->{3.427200822703125*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{753, 1048},
WindowMargins->{{Automatic, 540}, {11, Automatic}},
Magnification->1.25,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 358, 7, 237, "Title"],
Cell[951, 32, 145, 2, 35, "Subsubtitle"],
Cell[1099, 36, 165, 5, 60, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1289, 45, 108, 1, 88, "Section"],
Cell[1400, 48, 318, 6, 55, "Text"],
Cell[1721, 56, 980, 25, 48, "DisplayFormulaNumbered"],
Cell[2704, 83, 152, 3, 34, "Text"],
Cell[2859, 88, 1407, 37, 58, "DisplayFormulaNumbered"],
Cell[4269, 127, 577, 19, 34, "Text"],
Cell[4849, 148, 1050, 24, 61, "DisplayFormulaNumbered"],
Cell[5902, 174, 1748, 45, 142, "Text"],
Cell[7653, 221, 737, 18, 60, "Text"],
Cell[8393, 241, 1034, 27, 54, "DisplayFormulaNumbered"],
Cell[9430, 270, 334, 6, 34, "Text"],
Cell[9767, 278, 1304, 35, 50, "DisplayFormulaNumbered"],
Cell[11074, 315, 558, 12, 76, "Text"],
Cell[11635, 329, 647, 11, 76, "Text"],
Cell[12285, 342, 1567, 39, 50, "DisplayFormulaNumbered"],
Cell[13855, 383, 135, 2, 34, "Text"],
Cell[13993, 387, 1208, 25, 45, "DisplayFormulaNumbered"],
Cell[15204, 414, 133, 2, 34, "Text"],
Cell[15340, 418, 1501, 33, 45, "DisplayFormulaNumbered"],
Cell[16844, 453, 1583, 35, 45, "DisplayFormulaNumbered"],
Cell[18430, 490, 1678, 36, 45, "DisplayFormulaNumbered"],
Cell[20111, 528, 577, 12, 76, "Text"],
Cell[20691, 542, 1610, 34, 45, "DisplayFormulaNumbered"],
Cell[22304, 578, 576, 15, 76, "Text"],
Cell[22883, 595, 2510, 62, 84, "DisplayFormulaNumbered"],
Cell[25396, 659, 413, 10, 55, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25846, 674, 101, 1, 88, "Section"],
Cell[25950, 677, 653, 20, 55, "Text"],
Cell[26606, 699, 921, 19, 33, "DisplayFormulaNumbered"],
Cell[27530, 720, 210, 4, 55, "Text"],
Cell[27743, 726, 632, 13, 97, "Text"],
Cell[28378, 741, 2128, 51, 97, "Text"],
Cell[30509, 794, 634, 19, 58, "DisplayFormulaNumbered"],
Cell[31146, 815, 1392, 38, 97, "Text"],
Cell[32541, 855, 1758, 55, 50, "DisplayFormulaNumbered"],
Cell[34302, 912, 308, 6, 34, "Text"],
Cell[34613, 920, 499, 13, 33, "DisplayFormulaNumbered"],
Cell[35115, 935, 650, 17, 55, "Text"],
Cell[35768, 954, 1442, 45, 50, "DisplayFormulaNumbered"],
Cell[37213, 1001, 547, 9, 97, "Text"],
Cell[37763, 1012, 1388, 41, 45, "DisplayFormulaNumbered"],
Cell[39154, 1055, 146, 2, 34, "Text"],
Cell[39303, 1059, 957, 25, 45, "DisplayFormulaNumbered"],
Cell[40263, 1086, 338, 7, 55, "Text"],
Cell[40604, 1095, 1202, 33, 45, "DisplayFormulaNumbered"],
Cell[41809, 1130, 457, 11, 55, "Text"],
Cell[42269, 1143, 637, 19, 58, "DisplayFormulaNumbered"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42943, 1167, 93, 1, 88, "Section"],
Cell[43039, 1170, 704, 11, 117, "Text"],
Cell[43746, 1183, 1064, 21, 33, "DisplayFormulaNumbered"],
Cell[44813, 1206, 207, 2, 34, "Text"],
Cell[45023, 1210, 1575, 38, 58, "DisplayFormulaNumbered"],
Cell[46601, 1250, 115, 1, 34, "Text"],
Cell[46719, 1253, 1411, 33, 58, "DisplayFormulaNumbered"],
Cell[48133, 1288, 1006, 25, 99, "Text"],
Cell[49142, 1315, 601, 10, 97, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49780, 1330, 93, 1, 88, "Section"],
Cell[49876, 1333, 1227, 25, 55, "Text"],
Cell[51106, 1360, 1763, 40, 234, "Input"],
Cell[52872, 1402, 2375, 48, 117, "Text"],
Cell[55250, 1452, 3218, 83, 475, "Input"],
Cell[58471, 1537, 1167, 23, 76, "Text"],
Cell[59641, 1562, 1565, 42, 265, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61243, 1609, 87, 1, 88, "Section"],
Cell[61333, 1612, 4232, 93, 249, "Input"],
Cell[CellGroupData[{
Cell[65590, 1709, 1749, 31, 58, "Input"],
Cell[67342, 1742, 134589, 2209, 285, 127822, 2100, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[201968, 3956, 976, 23, 58, "Input"],
Cell[202947, 3981, 981, 23, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[203965, 4009, 663, 18, 58, "Input"],
Cell[204631, 4029, 2110, 54, 84, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[206778, 4088, 1007, 24, 58, "Input"],
Cell[207788, 4114, 827, 21, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[208652, 4140, 1132, 29, 80, "Input"],
Cell[209787, 4171, 950, 24, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210774, 4200, 645, 19, 58, "Input"],
Cell[211422, 4221, 1930, 58, 80, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[213389, 4284, 710, 22, 137, "Input"],
Cell[214102, 4308, 183, 5, 35, "Output"],
Cell[214288, 4315, 108, 1, 35, "Output"],
Cell[214399, 4318, 108, 1, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[214544, 4324, 709, 22, 137, "Input"],
Cell[215256, 4348, 183, 5, 35, "Output"],
Cell[215442, 4355, 111, 1, 35, "Output"],
Cell[215556, 4358, 113, 1, 35, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
